@@ -6,7 +6,9 @@ pmat <- function(x, start = -6, end = 9, vnames = NULL) {
   month.ids <- c(-1:-12, 1:12)
   used.months <- months[which(month.ids == start):which(month.ids == end)]
   no.months <- length(used.months)
-                                        # check for specified variable names, else default to colnames of x, if not present to V1, V2 etc.
+
+  ## check for specified variable names, else default to colnames of
+  ## x, if not present to V1, V2 etc.
   if (is.null(vnames) || length(unique(vnames)) != no.vars) {
     if (!is.null(colnames(x))) {
       vnames <- colnames(x)[3:(no.vars+2)]		
@@ -14,13 +16,17 @@ pmat <- function(x, start = -6, end = 9, vnames = NULL) {
       vnames <- paste(rep("V", no.vars), 1:no.vars, sep = "")
     }	
   }
-  vnames.mat <- matrix(NA, nrow = no.months, ncol = no.vars) # create unique names for variables
+
+  ## create unique names for variables
+  vnames.mat <- matrix(NA, nrow = no.months, ncol = no.vars) 
   for (i in 1:no.vars) {
     vnames.mat[, i] <- paste(vnames[i], ".", used.months, sep = "")
   }
+  
   m <- matrix(NA, nrow = no.months*no.vars, ncol = n - 1)
   colnames(m) <- years[-1]
   rownames(m) <- as.vector(vnames.mat)
+  
   for (i in 2:n) {
     if (start < 0) {
       start.with <- which(x[, 1] == years[i - 1])[abs(start)] # start month in previous year
@@ -33,7 +39,10 @@ pmat <- function(x, start = -6, end = 9, vnames = NULL) {
       }
     }
   }
+  
   pmatrix <- as.data.frame(t(m))
   attributes(pmatrix)$npar <- no.vars
+  
   pmatrix
 }
+
